@@ -2,7 +2,6 @@
 // File:        alignedblob.cpp
 // Description: Subclass of BBGrid to find vertically aligned blobs.
 // Author:      Ray Smith
-// Created:     Fri Mar 21 15:03:01 PST 2008
 //
 // (C) Copyright 2008, Google Inc.
 // Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,23 +17,31 @@
 ///////////////////////////////////////////////////////////////////////
 
 #ifdef HAVE_CONFIG_H
-#include "config_auto.h"
+#  include "config_auto.h"
 #endif
 
 #include "alignedblob.h"
 
 #include <algorithm>
 
+namespace tesseract {
+
 INT_VAR(textord_debug_tabfind, 0, "Debug tab finding");
 INT_VAR(textord_debug_bugs, 0, "Turn on output related to bugs in tab finding");
-INT_VAR(textord_testregion_left, -1, "Left edge of debug reporting rectangle");
-INT_VAR(textord_testregion_top, -1, "Top edge of debug reporting rectangle");
-INT_VAR(textord_testregion_right, INT32_MAX, "Right edge of debug rectangle");
-INT_VAR(textord_testregion_bottom, INT32_MAX, "Bottom edge of debug rectangle");
+static INT_VAR(textord_testregion_left, -1,
+               "Left edge of debug reporting rectangle in Leptonica coords "
+               "(bottom=0/top=height), with horizontal lines x/y-flipped");
+static INT_VAR(textord_testregion_top, INT32_MAX,
+               "Top edge of debug reporting rectangle in Leptonica coords "
+               "(bottom=0/top=height), with horizontal lines x/y-flipped");
+static INT_VAR(textord_testregion_right, INT32_MAX,
+               "Right edge of debug rectangle in Leptonica coords "
+               "(bottom=0/top=height), with horizontal lines x/y-flipped");
+static INT_VAR(textord_testregion_bottom, -1,
+               "Bottom edge of debug rectangle in Leptonica coords "
+               "(bottom=0/top=height), with horizontal lines x/y-flipped");
 BOOL_VAR(textord_debug_printable, false, "Make debug windows printable");
 
-namespace tesseract {
-
 // Fraction of resolution used as alignment tolerance for aligned tabs.
 const double kAlignedFraction = 0.03125;
 // Fraction of resolution used as alignment tolerance for ragged tabs.
@@ -54,7 +61,7 @@ const int kMinRaggedTabs = 5;
 // Min number of points to accept for an aligned tab stop.
 const int kMinAlignedTabs = 4;
 // Constant number of pixels minimum height of a vertical line.
-const int kVLineMinLength = 500;
+const int kVLineMinLength = 300;
 // Minimum gradient for a vertical tab vector. Used to prune away junk
 // tab vectors with what would be a ridiculously large skew angle.
 // Value corresponds to tan(90 - max allowed skew angle)
@@ -71,15 +78,13 @@ const int kMaxSkewFactor = 15;
 // on vertical gap before giving up and calling the line ended.
 // resolution is the original image resolution, and align0 indicates the
 // type of tab stop to be found.
-AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y,
-                                     int height, int v_gap_multiple,
-                                     int min_gutter_width,
-                                     int resolution, TabAlignment align0)
-  : right_tab(align0 == TA_RIGHT_RAGGED || align0 == TA_RIGHT_ALIGNED),
-    ragged(align0 == TA_LEFT_RAGGED || align0 == TA_RIGHT_RAGGED),
-    alignment(align0),
-    confirmed_type(TT_CONFIRMED),
-    min_length(0) {
+AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y, int height, int v_gap_multiple,
+                                     int min_gutter_width, int resolution, TabAlignment align0)
+    : right_tab(align0 == TA_RIGHT_RAGGED || align0 == TA_RIGHT_ALIGNED)
+    , ragged(align0 == TA_LEFT_RAGGED || align0 == TA_RIGHT_RAGGED)
+    , alignment(align0)
+    , confirmed_type(TT_CONFIRMED)
+    , min_length(0) {
   // Set the tolerances according to the type of line sought.
   // For tab search, these are based on the image resolution for most, or
   // the height of the starting blob for the maximum vertical gap.
@@ -103,8 +108,9 @@ AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y,
     min_points = kMinAlignedTabs;
   }
   min_gutter = static_cast<int>(height * gutter_fraction + 0.5);
-  if (min_gutter < min_gutter_width)
+  if (min_gutter < min_gutter_width) {
     min_gutter = min_gutter_width;
+  }
   // Fit the vertical vector into an ICOORD, which is 16 bit.
   set_vertical(vertical_x, vertical_y);
 }
@@ -112,17 +118,16 @@ AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y,
 // Constructor to set the parameters for finding vertical lines.
 // Vertical_x and vertical_y are the current estimates of the true vertical
 // direction (up) in the image. Width is the width of the starter blob.
-AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y,
-                                     int width)
-  : gutter_fraction(0.0),
-    right_tab(false),
-    ragged(false),
-    alignment(TA_SEPARATOR),
-    confirmed_type(TT_VLINE),
-    max_v_gap(kVLineSearchSize),
-    min_gutter(kVLineGutter),
-    min_points(1),
-    min_length(kVLineMinLength) {
+AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y, int width)
+    : gutter_fraction(0.0)
+    , right_tab(false)
+    , ragged(false)
+    , alignment(TA_SEPARATOR)
+    , confirmed_type(TT_VLINE)
+    , max_v_gap(kVLineSearchSize)
+    , min_gutter(kVLineGutter)
+    , min_points(1)
+    , min_length(kVLineMinLength) {
   // Compute threshold for left and right alignment.
   l_align_tolerance = std::max(kVLineAlignment, width);
   r_align_tolerance = std::max(kVLineAlignment, width);
@@ -134,76 +139,79 @@ AlignedBlobParams::AlignedBlobParams(int vertical_x, int vertical_y,
 // Fit the vertical vector into an ICOORD, which is 16 bit.
 void AlignedBlobParams::set_vertical(int vertical_x, int vertical_y) {
   int factor = 1;
-  if (vertical_y > INT16_MAX)
+  if (vertical_y > INT16_MAX) {
     factor = vertical_y / INT16_MAX + 1;
+  }
   vertical.set_x(vertical_x / factor);
   vertical.set_y(vertical_y / factor);
 }
 
-
-AlignedBlob::AlignedBlob(int gridsize,
-                         const ICOORD& bleft, const ICOORD& tright)
-  : BlobGrid(gridsize, bleft, tright) {
-}
+AlignedBlob::AlignedBlob(int gridsize, const ICOORD &bleft, const ICOORD &tright)
+    : BlobGrid(gridsize, bleft, tright) {}
 
 // Return true if the given coordinates are within the test rectangle
 // and the debug level is at least the given detail level.
 bool AlignedBlob::WithinTestRegion(int detail_level, int x, int y) {
-  if (textord_debug_tabfind < detail_level)
+  if (textord_debug_tabfind < detail_level) {
     return false;
+  }
   return x >= textord_testregion_left && x <= textord_testregion_right &&
          y <= textord_testregion_top && y >= textord_testregion_bottom;
 }
 
-// Display the tab codes of the BLOBNBOXes in this grid.
-ScrollView* AlignedBlob::DisplayTabs(const char* window_name,
-                                     ScrollView* tab_win) {
 #ifndef GRAPHICS_DISABLED
-  if (tab_win == nullptr)
+
+// Display the tab codes of the BLOBNBOXes in this grid.
+ScrollView *AlignedBlob::DisplayTabs(const char *window_name, ScrollView *tab_win) {
+  if (tab_win == nullptr) {
     tab_win = MakeWindow(0, 50, window_name);
+  }
   // For every tab in the grid, display it.
   GridSearch<BLOBNBOX, BLOBNBOX_CLIST, BLOBNBOX_C_IT> gsearch(this);
   gsearch.StartFullSearch();
-  BLOBNBOX* bbox;
+  BLOBNBOX *bbox;
   while ((bbox = gsearch.NextFullSearch()) != nullptr) {
-    const TBOX& box = bbox->bounding_box();
+    const TBOX &box = bbox->bounding_box();
     int left_x = box.left();
     int right_x = box.right();
     int top_y = box.top();
     int bottom_y = box.bottom();
     TabType tabtype = bbox->left_tab_type();
     if (tabtype != TT_NONE) {
-      if (tabtype == TT_MAYBE_ALIGNED)
+      if (tabtype == TT_MAYBE_ALIGNED) {
         tab_win->Pen(ScrollView::BLUE);
-      else if (tabtype == TT_MAYBE_RAGGED)
+      } else if (tabtype == TT_MAYBE_RAGGED) {
         tab_win->Pen(ScrollView::YELLOW);
-      else if (tabtype == TT_CONFIRMED)
+      } else if (tabtype == TT_CONFIRMED) {
         tab_win->Pen(ScrollView::GREEN);
-      else
+      } else {
         tab_win->Pen(ScrollView::GREY);
+      }
       tab_win->Line(left_x, top_y, left_x, bottom_y);
     }
     tabtype = bbox->right_tab_type();
     if (tabtype != TT_NONE) {
-      if (tabtype == TT_MAYBE_ALIGNED)
+      if (tabtype == TT_MAYBE_ALIGNED) {
         tab_win->Pen(ScrollView::MAGENTA);
-      else if (tabtype == TT_MAYBE_RAGGED)
+      } else if (tabtype == TT_MAYBE_RAGGED) {
         tab_win->Pen(ScrollView::ORANGE);
-      else if (tabtype == TT_CONFIRMED)
+      } else if (tabtype == TT_CONFIRMED) {
         tab_win->Pen(ScrollView::RED);
-      else
+      } else {
         tab_win->Pen(ScrollView::GREY);
+      }
       tab_win->Line(right_x, top_y, right_x, bottom_y);
     }
   }
   tab_win->Update();
-#endif
   return tab_win;
 }
 
+#endif // !GRAPHICS_DISABLED
+
 // Helper returns true if the total number of line_crossings of all the blobs
 // in the list is at least 2.
-static bool AtLeast2LineCrossings(BLOBNBOX_CLIST* blobs) {
+static bool AtLeast2LineCrossings(BLOBNBOX_CLIST *blobs) {
   BLOBNBOX_C_IT it(blobs);
   int total_crossings = 0;
   for (it.mark_cycle_pt(); !it.cycled_list(); it.forward()) {
@@ -223,10 +231,8 @@ AlignedBlob::~AlignedBlob() = default;
 // vertical_x and y are updated with an estimate of the real
 // vertical direction. (skew finding.)
 // Returns nullptr if no decent vector can be found.
-TabVector* AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params,
-                                              BLOBNBOX* bbox,
-                                              int* vertical_x,
-                                              int* vertical_y) {
+TabVector *AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params, BLOBNBOX *bbox,
+                                              int *vertical_x, int *vertical_y) {
   int ext_start_y, ext_end_y;
   BLOBNBOX_CLIST good_points;
   // Search up and then down from the starting bbox.
@@ -249,30 +255,29 @@ TabVector* AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params,
   // Ragged tabs don't need to satisfy the gradient condition, as they
   // will always end up parallel to the vertical direction.
   bool at_least_2_crossings = AtLeast2LineCrossings(&good_points);
-  if ((pt_count >= align_params.min_points &&
-      end_y - start_y >= align_params.min_length &&
-      (align_params.ragged ||
-          end_y - start_y >= abs(end_x - start_x) * kMinTabGradient)) ||
+  if ((pt_count >= align_params.min_points && end_y - start_y >= align_params.min_length &&
+       (align_params.ragged || end_y - start_y >= abs(end_x - start_x) * kMinTabGradient)) ||
       at_least_2_crossings) {
     int confirmed_points = 0;
     // Count existing confirmed points to see if vector is acceptable.
     for (it.mark_cycle_pt(); !it.cycled_list(); it.forward()) {
       bbox = it.data();
       if (align_params.right_tab) {
-        if (bbox->right_tab_type() == align_params.confirmed_type)
+        if (bbox->right_tab_type() == align_params.confirmed_type) {
           ++confirmed_points;
+        }
       } else {
-        if (bbox->left_tab_type() == align_params.confirmed_type)
+        if (bbox->left_tab_type() == align_params.confirmed_type) {
           ++confirmed_points;
+        }
       }
     }
     // Ragged vectors are not allowed to use too many already used points.
-    if (!align_params.ragged ||
-        confirmed_points + confirmed_points < pt_count) {
-      const TBOX& box = bbox->bounding_box();
+    if (!align_params.ragged || confirmed_points + confirmed_points < pt_count) {
+      const TBOX &box = bbox->bounding_box();
       if (debug) {
-        tprintf("Confirming tab vector of %d pts starting at %d,%d\n",
-                pt_count, box.left(), box.bottom());
+        tprintf("Confirming tab vector of %d pts starting at %d,%d\n", pt_count, box.left(),
+                box.bottom());
       }
       // Flag all the aligned neighbours as confirmed .
       for (it.mark_cycle_pt(); !it.cycled_list(); it.forward()) {
@@ -287,11 +292,9 @@ TabVector* AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params,
         }
       }
       // Now make the vector and return it.
-      TabVector* result = TabVector::FitVector(align_params.alignment,
-                                               align_params.vertical,
-                                               ext_start_y, ext_end_y,
-                                               &good_points,
-                                               vertical_x, vertical_y);
+      TabVector *result =
+          TabVector::FitVector(align_params.alignment, align_params.vertical, ext_start_y,
+                               ext_end_y, &good_points, vertical_x, vertical_y);
       result->set_intersects_other_lines(at_least_2_crossings);
       if (debug) {
         tprintf("Box was %d, %d\n", box.left(), box.bottom());
@@ -299,14 +302,14 @@ TabVector* AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params,
       }
       return result;
     } else if (debug) {
-      tprintf("Ragged tab used too many used points: %d out of %d\n",
-              confirmed_points, pt_count);
+      tprintf("Ragged tab used too many used points: %d out of %d\n", confirmed_points, pt_count);
     }
   } else if (debug) {
-    tprintf("Tab vector failed basic tests: pt count %d vs min %d, "
-            "length %d vs min %d, min grad %g\n",
-            pt_count, align_params.min_points, end_y - start_y,
-            align_params.min_length, abs(end_x - start_x) * kMinTabGradient);
+    tprintf(
+        "Tab vector failed basic tests: pt count %d vs min %d, "
+        "length %d vs min %d, min grad %g\n",
+        pt_count, align_params.min_points, end_y - start_y, align_params.min_length,
+        abs(end_x - start_x) * kMinTabGradient);
   }
   return nullptr;
 }
@@ -315,9 +318,8 @@ TabVector* AlignedBlob::FindVerticalAlignment(AlignedBlobParams align_params,
 // direction with the given blob. Returns a list of aligned
 // blobs and the number in the list.
 // For other parameters see FindAlignedBlob below.
-int AlignedBlob::AlignTabs(const AlignedBlobParams& params,
-                           bool top_to_bottom, BLOBNBOX* bbox,
-                           BLOBNBOX_CLIST* good_points, int* end_y) {
+int AlignedBlob::AlignTabs(const AlignedBlobParams &params, bool top_to_bottom, BLOBNBOX *bbox,
+                           BLOBNBOX_CLIST *good_points, int *end_y) {
   int ptcount = 0;
   BLOBNBOX_C_IT it(good_points);
 
@@ -331,14 +333,14 @@ int AlignedBlob::AlignTabs(const AlignedBlobParams& params,
   while (bbox != nullptr) {
     // Add the blob to the list if the appropriate side is a tab candidate,
     // or if we are working on a ragged tab.
-    TabType type = params.right_tab ? bbox->right_tab_type()
-                                    : bbox->left_tab_type();
+    TabType type = params.right_tab ? bbox->right_tab_type() : bbox->left_tab_type();
     if (((type != TT_NONE && type != TT_MAYBE_RAGGED) || params.ragged) &&
         (it.empty() || it.data() != bbox)) {
-      if (top_to_bottom)
+      if (top_to_bottom) {
         it.add_before_then_move(bbox);
-      else
+      } else {
         it.add_after_then_move(bbox);
+      }
       ++ptcount;
     }
     // Find the next blob that is aligned with the current one.
@@ -348,8 +350,9 @@ int AlignedBlob::AlignTabs(const AlignedBlobParams& params,
     bbox = FindAlignedBlob(params, top_to_bottom, bbox, x_start, end_y);
     if (bbox != nullptr) {
       box = bbox->bounding_box();
-      if (!params.ragged)
+      if (!params.ragged) {
         x_start = params.right_tab ? box.right() : box.left();
+      }
     }
   }
   if (debug) {
@@ -366,9 +369,8 @@ int AlignedBlob::AlignTabs(const AlignedBlobParams& params,
 // or if a blob was found in the gutter. On a nullptr return, end_y
 // is set to the edge of the search box or the leading edge of the
 // gutter blob if one was found.
-BLOBNBOX* AlignedBlob::FindAlignedBlob(const AlignedBlobParams& p,
-                                       bool top_to_bottom, BLOBNBOX* bbox,
-                                       int x_start, int* end_y) {
+BLOBNBOX *AlignedBlob::FindAlignedBlob(const AlignedBlobParams &p, bool top_to_bottom,
+                                       BLOBNBOX *bbox, int x_start, int *end_y) {
   TBOX box = bbox->bounding_box();
   // If there are separator lines, get the column edges.
   int left_column_edge = bbox->left_rule();
@@ -378,17 +380,16 @@ BLOBNBOX* AlignedBlob::FindAlignedBlob(const AlignedBlobParams& p,
   // line beyond start_y.
   int start_y = top_to_bottom ? box.bottom() : box.top();
   if (WithinTestRegion(2, x_start, start_y)) {
-    tprintf("Column edges for blob at (%d,%d)->(%d,%d) are [%d, %d]\n",
-            box.left(), box.top(), box.right(), box.bottom(),
-            left_column_edge, right_column_edge);
+    tprintf("Column edges for blob at (%d,%d)->(%d,%d) are [%d, %d]\n", box.left(), box.top(),
+            box.right(), box.bottom(), left_column_edge, right_column_edge);
   }
   // Compute skew tolerance.
   int skew_tolerance = p.max_v_gap / kMaxSkewFactor;
   // Calculate xmin and xmax of the search box so that it contains
-  // all possibly relevant boxes up to p.max_v_gap above or below accoording
+  // all possibly relevant boxes up to p.max_v_gap above or below according
   // to top_to_bottom.
   // Start with a notion of vertical with the current estimate.
-  int x2 = (p.max_v_gap * p.vertical.x() + p.vertical.y()/2) / p.vertical.y();
+  int x2 = (p.max_v_gap * p.vertical.x() + p.vertical.y() / 2) / p.vertical.y();
   if (top_to_bottom) {
     x2 = x_start - x2;
     *end_y = start_y - p.max_v_gap;
@@ -409,100 +410,107 @@ BLOBNBOX* AlignedBlob::FindAlignedBlob(const AlignedBlobParams& p,
   }
   // Setup a vertical search for an aligned blob.
   GridSearch<BLOBNBOX, BLOBNBOX_CLIST, BLOBNBOX_C_IT> vsearch(this);
-  if (WithinTestRegion(2, x_start, start_y))
+  if (WithinTestRegion(2, x_start, start_y)) {
     tprintf("Starting %s %s search at %d-%d,%d, search_size=%d, gutter=%d\n",
-            p.ragged ? "Ragged" : "Aligned", p.right_tab ? "Right" : "Left",
-            xmin, xmax, start_y, p.max_v_gap, p.min_gutter);
+            p.ragged ? "Ragged" : "Aligned", p.right_tab ? "Right" : "Left", xmin, xmax, start_y,
+            p.max_v_gap, p.min_gutter);
+  }
   vsearch.StartVerticalSearch(xmin, xmax, start_y);
   // result stores the best real return value.
-  BLOBNBOX* result = nullptr;
+  BLOBNBOX *result = nullptr;
   // The backup_result is not a tab candidate and can be used if no
   // real tab candidate result is found.
-  BLOBNBOX* backup_result = nullptr;
+  BLOBNBOX *backup_result = nullptr;
   // neighbour is the blob that is currently being investigated.
-  BLOBNBOX* neighbour = nullptr;
+  BLOBNBOX *neighbour = nullptr;
   while ((neighbour = vsearch.NextVerticalSearch(top_to_bottom)) != nullptr) {
-    if (neighbour == bbox)
+    if (neighbour == bbox) {
       continue;
+    }
     TBOX nbox = neighbour->bounding_box();
     int n_y = (nbox.top() + nbox.bottom()) / 2;
     if ((!top_to_bottom && n_y > start_y + p.max_v_gap) ||
         (top_to_bottom && n_y < start_y - p.max_v_gap)) {
-      if (WithinTestRegion(2, x_start, start_y))
-        tprintf("Neighbour too far at (%d,%d)->(%d,%d)\n",
-                nbox.left(), nbox.bottom(), nbox.right(), nbox.top());
-      break;  // Gone far enough.
+      if (WithinTestRegion(2, x_start, start_y)) {
+        tprintf("Neighbour too far at (%d,%d)->(%d,%d)\n", nbox.left(), nbox.bottom(), nbox.right(),
+                nbox.top());
+      }
+      break; // Gone far enough.
     }
     // It is CRITICAL to ensure that forward progress is made, (strictly
     // in/decreasing n_y) or the caller could loop infinitely, while
     // waiting for a sequence of blobs in a line to end.
     // NextVerticalSearch alone does not guarantee this, as there may be
     // more than one blob in a grid cell. See comment in AlignTabs.
-    if ((n_y < start_y) != top_to_bottom || nbox.y_overlap(box))
-      continue;  // Only look in the required direction.
-    if (result != nullptr && result->bounding_box().y_gap(nbox) > gridsize())
-      return result;  // This result is clear.
+    if ((n_y < start_y) != top_to_bottom || nbox.y_overlap(box)) {
+      continue; // Only look in the required direction.
+    }
+    if (result != nullptr && result->bounding_box().y_gap(nbox) > gridsize()) {
+      return result; // This result is clear.
+    }
     if (backup_result != nullptr && p.ragged && result == nullptr &&
-        backup_result->bounding_box().y_gap(nbox) > gridsize())
-      return backup_result;  // This result is clear.
+        backup_result->bounding_box().y_gap(nbox) > gridsize()) {
+      return backup_result; // This result is clear.
+    }
 
     // If the neighbouring blob is the wrong side of a separator line, then it
     // "doesn't exist" as far as we are concerned.
     int x_at_n_y = x_start + (n_y - start_y) * p.vertical.x() / p.vertical.y();
-    if (x_at_n_y < neighbour->left_crossing_rule() ||
-        x_at_n_y > neighbour->right_crossing_rule())
-      continue;  // Separator line in the way.
+    if (x_at_n_y < neighbour->left_crossing_rule() || x_at_n_y > neighbour->right_crossing_rule()) {
+      continue; // Separator line in the way.
+    }
     int n_left = nbox.left();
     int n_right = nbox.right();
     int n_x = p.right_tab ? n_right : n_left;
-    if (WithinTestRegion(2, x_start, start_y))
-      tprintf("neighbour at (%d,%d)->(%d,%d), n_x=%d, n_y=%d, xatn=%d\n",
-              nbox.left(), nbox.bottom(), nbox.right(), nbox.top(),
-              n_x, n_y, x_at_n_y);
-    if (p.right_tab &&
-        n_left < x_at_n_y + p.min_gutter &&
+    if (WithinTestRegion(2, x_start, start_y)) {
+      tprintf("neighbour at (%d,%d)->(%d,%d), n_x=%d, n_y=%d, xatn=%d\n", nbox.left(),
+              nbox.bottom(), nbox.right(), nbox.top(), n_x, n_y, x_at_n_y);
+    }
+    if (p.right_tab && n_left < x_at_n_y + p.min_gutter &&
         n_right > x_at_n_y + p.r_align_tolerance &&
         (p.ragged || n_left < x_at_n_y + p.gutter_fraction * nbox.height())) {
       // In the gutter so end of line.
-      if (bbox->right_tab_type() >= TT_MAYBE_ALIGNED)
+      if (bbox->right_tab_type() >= TT_MAYBE_ALIGNED) {
         bbox->set_right_tab_type(TT_DELETED);
+      }
       *end_y = top_to_bottom ? nbox.top() : nbox.bottom();
-      if (WithinTestRegion(2, x_start, start_y))
+      if (WithinTestRegion(2, x_start, start_y)) {
         tprintf("gutter\n");
+      }
       return nullptr;
     }
-    if (!p.right_tab &&
-        n_left < x_at_n_y - p.l_align_tolerance &&
+    if (!p.right_tab && n_left < x_at_n_y - p.l_align_tolerance &&
         n_right > x_at_n_y - p.min_gutter &&
         (p.ragged || n_right > x_at_n_y - p.gutter_fraction * nbox.height())) {
       // In the gutter so end of line.
-      if (bbox->left_tab_type() >= TT_MAYBE_ALIGNED)
+      if (bbox->left_tab_type() >= TT_MAYBE_ALIGNED) {
         bbox->set_left_tab_type(TT_DELETED);
+      }
       *end_y = top_to_bottom ? nbox.top() : nbox.bottom();
-      if (WithinTestRegion(2, x_start, start_y))
+      if (WithinTestRegion(2, x_start, start_y)) {
         tprintf("gutter\n");
+      }
       return nullptr;
     }
     if ((p.right_tab && neighbour->leader_on_right()) ||
-        (!p.right_tab && neighbour->leader_on_left()))
-      continue;  // Neighbours of leaders are not allowed to be used.
-    if (n_x <= x_at_n_y + p.r_align_tolerance &&
-        n_x >= x_at_n_y - p.l_align_tolerance) {
+        (!p.right_tab && neighbour->leader_on_left())) {
+      continue; // Neighbours of leaders are not allowed to be used.
+    }
+    if (n_x <= x_at_n_y + p.r_align_tolerance && n_x >= x_at_n_y - p.l_align_tolerance) {
       // Aligned so keep it. If it is a marked tab save it as result,
       // otherwise keep it as backup_result to return in case of later failure.
-      if (WithinTestRegion(2, x_start, start_y))
-        tprintf("aligned, seeking%d, l=%d, r=%d\n",
-                p.right_tab, neighbour->left_tab_type(),
+      if (WithinTestRegion(2, x_start, start_y)) {
+        tprintf("aligned, seeking%d, l=%d, r=%d\n", p.right_tab, neighbour->left_tab_type(),
                 neighbour->right_tab_type());
-      TabType n_type = p.right_tab ? neighbour->right_tab_type()
-                                   : neighbour->left_tab_type();
+      }
+      TabType n_type = p.right_tab ? neighbour->right_tab_type() : neighbour->left_tab_type();
       if (n_type != TT_NONE && (p.ragged || n_type != TT_MAYBE_RAGGED)) {
         if (result == nullptr) {
           result = neighbour;
         } else {
           // Keep the closest neighbour by Euclidean distance.
           // This prevents it from picking a tab blob in another column.
-          const TBOX& old_box = result->bounding_box();
+          const TBOX &old_box = result->bounding_box();
           int x_diff = p.right_tab ? old_box.right() : old_box.left();
           x_diff -= x_at_n_y;
           int y_diff = (old_box.top() + old_box.bottom()) / 2 - start_y;
@@ -510,19 +518,22 @@ BLOBNBOX* AlignedBlob::FindAlignedBlob(const AlignedBlobParams& p,
           x_diff = n_x - x_at_n_y;
           y_diff = n_y - start_y;
           int new_dist = x_diff * x_diff + y_diff * y_diff;
-          if (new_dist < old_dist)
+          if (new_dist < old_dist) {
             result = neighbour;
+          }
         }
       } else if (backup_result == nullptr) {
-        if (WithinTestRegion(2, x_start, start_y))
+        if (WithinTestRegion(2, x_start, start_y)) {
           tprintf("Backup\n");
+        }
         backup_result = neighbour;
       } else {
         TBOX backup_box = backup_result->bounding_box();
         if ((p.right_tab && backup_box.right() < nbox.right()) ||
             (!p.right_tab && backup_box.left() > nbox.left())) {
-          if (WithinTestRegion(2, x_start, start_y))
+          if (WithinTestRegion(2, x_start, start_y)) {
             tprintf("Better backup\n");
+          }
           backup_result = neighbour;
         }
       }
@@ -531,4 +542,4 @@ BLOBNBOX* AlignedBlob::FindAlignedBlob(const AlignedBlobParams& p,
   return result != nullptr ? result : backup_result;
 }
 
-}  // namespace tesseract.
+} // namespace tesseract.
